@@ -28,8 +28,8 @@ class JKSparkSession(object):
     @classmethod
     def get(cls):
         for key, value in cls._options.items():
-            cls._spark.config(key,value)
-        cls._spark.getOrCreate()
+            cls._spark = cls._spark.config(key,value)
+        cls._spark = cls._spark.getOrCreate()
         return cls._spark
 
 
